<?php

namespace Drupal\access_policy\Plugin\AccessRule;

use Drupal\Core\Database\Query\SelectInterface;
use Drupal\Core\Entity\EntityInterface;
use Drupal\Core\Session\AccountInterface;
use Drupal\user\EntityOwnerInterface;

/**
 * Is authored by the current user.
 *
 * Checks to see if the entity was created by the current user.
 *
 * @AccessRule(
 *   id = "is_own",
 *   label = @Translation("Authored by current user"),
 *   description = @Translation("The entity was authored by the current user."),
 *   entity_types = {"node", "media"},
 * )
 */
class IsOwn extends AccessRuleBase {

  /**
   * {@inheritdoc}
   */
  public function isApplicable(EntityInterface $entity) {
    if ($entity instanceof EntityOwnerInterface) {
      return TRUE;
    }

    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function validate(EntityInterface $entity, AccountInterface $account) {
    if ($entity->getOwnerId() == $account->id()) {
      return TRUE;
    }

    return FALSE;
  }

  /**
   * {@inheritdoc}
   */
  public function queryAlter(SelectInterface $query, AccountInterface $user) {
    $access_policy = $this->getAccessPolicy();
    $entity_type = $access_policy->getTargetEntityType();

    $base_field_placeholder = $query->getMetaData('base_table') . '.' . $query->getMetaData('base_field');
    $data_table = $entity_type->getDataTable();
    $query->join($data_table, $data_table, $data_table . '.' . $entity_type->getKey('id') . '=' . $base_field_placeholder);
    $user_field = $data_table . '.' . $entity_type->getKey('uid');
    $query->condition($user_field, $user->id());
  }

}
